pytilities.test.delegation.delegation.A

Package pytilities :: Package test :: Package delegation :: Module delegation :: Class A |
[hide private]
[frames] | no frames]

# Class A

source code

    object --+
             |
            A

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
reset(self) | source code
f(self, a, b, c) | source code
g(self) | source code
Delegator(profile_name=`'``default``'`, target=None) Construct a delegator with a stored Profile. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| _delegator_factory = `<pytilities.delegation.delegatorfactory.D`...``

Properties | [hide private]
| x
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### f(self, a, b, c) | source code
Decorators: `@delegated("public")`

### g(self) | source code
Decorators: `@delegated()`

### Delegator(profile_name=`'``default``'`, target=None) | source code
Construct a delegator with a stored Profile. Parameters: `profile_name` :: string name of the Profile to use to set up the delegator with `target` = None target of the newly created delegator Returns newly created delegator :: Delegator Raises: `ValueError` when no profile with name `profile_name` exists

Class Variable Details | [hide private]

  ### _delegator_factory Value:
      <pytilities.delegation.delegatorfactory.DelegatorFactory object at 0x1
      c75d10>

Property Details | [hide private]

### x Get Method: unreachable.x(self) Set Method: unreachable.x(self, value)